@@ -1,5 +1,5 @@
 #
-# $Date: 2005/02/21 03:15:53 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Functions that wrap the execution of tools so that they are logged
 #
@@ -41,7 +41,7 @@ sub exec_pipe {
     my $cmd    = shift(@_);
 
     die "Can't open pipe for exec_pipe"
-      unless defined(my $pid = open($handle, "-|"));
+      unless defined(my $pid = open($handle, '-|'));
 
     if ($pid) {
         return $handle;
