@@ -1,5 +1,5 @@
 #
-# $Date: 2005/10/13 17:02:34 $
+# $Date: 2006/05/08 18:46:57 $
 #
 # File name layer functions
 #
@@ -135,6 +135,7 @@ sub main {
 # Sorting and display types
 my $FIL_SORT_ASC = 0;
 my $FIL_SORT_STR = 1;
+my $FIL_SORT_HEX = 2;
 
 # Methods of sorting the file listings
 my $SORT_DTYPE = 0;    # type according to dentry
@@ -1878,6 +1879,12 @@ sub content_menu {
       . "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::REPORT&"
       . "sort=$FIL_SORT_ASC$url\" target=\"_blank\">report</a>)</td>\n"
       . "<td>*</td>\n"
+      . "<td>Hex ("
+      . "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT&"
+      . "sort=$FIL_SORT_HEX$url\" target=\"cont2\">display</a> - "
+      . "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::REPORT&"
+      . "sort=$FIL_SORT_HEX$url\" target=\"_blank\">report</a>)</td>\n"
+      . "<td>*</td>\n"
       . "<td>ASCII Strings ("
       . "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT&"
       . "sort=$FIL_SORT_STR$url\" target=\"cont2\">display</a> - "
@@ -1953,10 +1960,25 @@ sub content {
 "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta"
         );
 
-        print "Contents Of File: $fname\n\n\n\n";
+        print "Contents Of File: $fname\n\n\n";
         Print::print_output($_) while ($_ = Exec::read_pipe_data(*OUT, 1024));
         close(OUT);
+    }
+    elsif ($sort == $FIL_SORT_HEX) {
+        Print::log_host_inv(
+            "$Caseman::vol2sname{$vol}: Viewing $fname ($meta) as Hex");
 
+        Exec::exec_pipe(*OUT,
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta"
+        );
+
+        print "Hex Contents Of File: $fname\n\n\n";
+        my $offset = 0;
+        while ($_ = Exec::read_pipe_data(*OUT, 1024)) {
+            Print::print_hexdump($_, $offset * 1024);
+            $offset++;
+        }
+        close(OUT);
     }
     elsif ($sort == $FIL_SORT_STR) {
         Print::log_host_inv(
@@ -2090,6 +2112,11 @@ sub report {
         );
         $type = "ASCII";
     }
+    elsif ($sort == $FIL_SORT_HEX) {
+        Print::log_host_inv(
+            "$Args::args{'vol'}: Generating Hex report for $fname ($meta)");
+        $type = "Hex";
+    }
     elsif ($sort == $FIL_SORT_STR) {
         Print::log_host_inv(
 "$Args::args{'vol'}: Generating ASCII strings report for $fname ($meta)"
@@ -2107,7 +2134,7 @@ sub report {
     # headers and will remove the second line.
     #
     print "                  Autopsy $type Report\n\n"
-      . "-" x 62 . "\n"
+      . "-" x 70 . "\n"
       . "                   GENERAL INFORMATION\n\n"
       . "File: $fname\n";
 
@@ -2188,7 +2215,7 @@ sub report {
     my $date = localtime();
     print "\nDate Generated: $date\n"
       . "Investigator: $Args::args{'inv'}\n\n"
-      . "-" x 62 . "\n"
+      . "-" x 70 . "\n"
       . "                   META DATA INFORMATION\n\n";
 
     # Get the meta details
@@ -2210,8 +2237,8 @@ sub report {
 
     print "\nFile Type: $apptype";
 
-    print "\n" . "-" x 62 . "\n";
-    if ($sort != $FIL_SORT_STR) {
+    print "\n" . "-" x 70 . "\n";
+    if ($sort == $FIL_SORT_ASC) {
         print "           CONTENT (Non-ASCII data may not be shown)\n\n";
     }
     else {
@@ -2225,6 +2252,17 @@ sub report {
         Print::print_output($_) while ($_ = Exec::read_pipe_data(*OUT, 1024));
         close(OUT);
     }
+    elsif ($sort == $FIL_SORT_HEX) {
+        Exec::exec_pipe(*OUT,
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta"
+        );
+        my $offset = 0;
+        while ($_ = Exec::read_pipe_data(*OUT, 1024)) {
+            Print::print_hexdump($_, $offset * 1024);
+            $offset++;
+        }
+        close(OUT);
+    }
     elsif ($sort == $FIL_SORT_STR) {
         Exec::exec_pipe(*OUT,
 "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a"
@@ -2234,7 +2272,7 @@ sub report {
     }
 
     print "\n"
-      . "-" x 62 . "\n"
+      . "-" x 70 . "\n"
       . "                   VERSION INFORMATION\n\n"
       . "Autopsy Version: $::VER\n";
     print "The Sleuth Kit Version: " . ::get_tskver() . "\n";
