@@ -1,5 +1,5 @@
 #
-# $Date: 2005/10/13 17:02:34 $
+# $Date: 2006/05/08 18:46:57 $
 #
 # Hash database and calculation functions
 #
@@ -466,6 +466,14 @@ sub int_menu_print {
               . "</form></td></tr>\n";
         }
 
+        # we currenly only support integrity for raw and split image formats
+        elsif (($Caseman::vol2itype{$sort[$i]} ne "raw")
+            && ($Caseman::vol2itype{$sort[$i]} ne "split"))
+        {
+            print
+"<td colspan=2>Integrity checks for image type $Caseman::vol2itype{$sort[$i]} not yet supported</td></tr>\n";
+        }
+
         # Generate New button
         else {
             print "<td>&nbsp;</td><td>"
