@@ -1,7 +1,7 @@
 package Print;
 
 #
-# $Date: 2005/10/13 17:02:34 $
+# $Date: 2006/05/08 18:46:57 $
 #
 # Utilities to print information
 #
@@ -51,27 +51,89 @@ sub html_encode {
 sub print_output {
     my $out = shift;
     print "$out";
-# This was removed because of Unicode support
-# perhaps later some more checks can be done...
-if (0) {
-    while (my $out = shift) {
-        foreach $_ (split(//, $out)) {
-            if (   ($_ eq "\n")
-                || ($_ eq "\r")
-                || ($_ eq "\f")
-                || ($_ eq "\t"))
-            {
-                print "$_";
-            }
-            elsif ((ord($_) < 0x20) || (ord($_) > 0x7e)) {
-                print "^" . ord($_);
-            }
-            else {
-                print "$_";
+
+    # This was removed because of Unicode support
+    # perhaps later some more checks can be done...
+    if (0) {
+        while (my $out = shift) {
+            foreach $_ (split(//, $out)) {
+                if (   ($_ eq "\n")
+                    || ($_ eq "\r")
+                    || ($_ eq "\f")
+                    || ($_ eq "\t"))
+                {
+                    print "$_";
+                }
+                elsif ((ord($_) < 0x20) || (ord($_) > 0x7e)) {
+                    print "^" . ord($_);
+                }
+                else {
+                    print "$_";
+                }
             }
         }
     }
 }
+
+# Added to provide output in hexdump format
+# function gets called on a per-icat basis,
+# The offset value is the byte offset that this data
+# starts at, since the File.pm code calls it in 1024
+# byte chunks)
+sub print_hexdump {
+    my $out    = shift;    # data to output
+    my $offset = shift;    # starting byte offset in file
+    my $buf    = "";
+
+    foreach $i (split(//, $out)) {
+        my $idx = $offset % 16;
+
+        if ($idx == 0) {
+            printf("%08X:  ", $offset);
+        }
+
+        printf("%02X", ord($i));
+        if (($idx % 2) == 1) {
+            printf(" ");
+        }
+
+        $buf[$idx] = $i;
+
+        if ($idx == 15) {
+            print "   ";
+            for (my $j = 0; $j < 16; $j++) {
+                if ($buf[$j] =~ m/[ -~]/) {
+                    print $buf[$j];
+                }
+                else {
+                    print ".";
+                }
+                $buf[$j] = 0;
+            }
+            print "\n";
+        }
+        $offset++;
+    }
+
+    # print out last line if < 16 bytes long
+    my $l = $offset % 16;
+
+    if ($l) {
+        my $t = (16 - $l) * 2 + (16 - $l) / 2;
+        for (my $j = 0; $j < $t; $j++) {
+            print " ";
+        }
+        print "   ";
+        for (my $j = 0; $j < $l; $j++) {
+            if ($buf[$j] =~ m/[ -~]/) {
+                print $buf[$j];
+            }
+            else {
+                print ".";
+            }
+        }
+        print "\n";
+    }
 }
 
 ############################################
