@@ -1,7 +1,7 @@
 #
 # Timeline functions
 #
-# $Date: 2005/03/16 00:03:40 $
+# $Date: 2005/10/13 17:02:34 $
 #
 # Brian Carrier [carrier@sleuthkit.org]
 # Copyright (c) 2001-2005 by Brian Carrier.  All rights reserved
@@ -1079,7 +1079,7 @@ sub tl_run {
     }
     else {
         print
-          "Comma delimited files cannot be viewed from withing Autopsy.<br>\n"
+          "Comma delimited files cannot be viewed from within Autopsy.<br>\n"
           . "Open it in a spreadsheet or other data processing tool.<br>\n";
     }
     Print::print_html_footer();
@@ -1201,7 +1201,7 @@ sub view_idx {
     my $tl_vol = Args::get_tl();
     my $tl     = $Caseman::vol2path{$tl_vol};
 
-    print "<center><font size=3>";
+    print "<center>";
     my $url =
         "$::PROGNAME?$Args::baseargs&mod=$::MOD_TL&view=$Timeline::VIEW_FR&"
       . "tl=$tl_vol";
